summary refs log tree commit diff stats
path: root/lib/pure/htmlgen.nim
diff options
context:
space:
mode:
authorringabout <43030857+ringabout@users.noreply.github.com>2023-10-31 00:03:04 +0800
committerGitHub <noreply@github.com>2023-10-30 17:03:04 +0100
commit4d11d0619d11d8aecdaff998981efcd054de9760 (patch)
treed098736002228d600e3232f6ab6d8347872224c8 /lib/pure/htmlgen.nim
parent403e0118ae8d099384e9bd6a046c2114538503b8 (diff)
downloadNim-4d11d0619d11d8aecdaff998981efcd054de9760.tar.gz
complete std prefixes for stdlib (#22887)
follow up https://github.com/nim-lang/Nim/pull/22851
follow up https://github.com/nim-lang/Nim/pull/22873
Diffstat (limited to 'lib/pure/htmlgen.nim')
-rw-r--r--lib/pure/htmlgen.nim4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/pure/htmlgen.nim b/lib/pure/htmlgen.nim
index be9e1fe90..fafa72463 100644
--- a/lib/pure/htmlgen.nim
+++ b/lib/pure/htmlgen.nim
@@ -8,7 +8,7 @@
 #
 
 ## Do yourself a favor and import the module
 ## as `from htmlgen import nil` and then fully qualify the macros.
 ##
 ## *Note*: The Karax project (`nimble install karax`) has a better
 ## way to achieve the same, see https://github.com/pragmagic/karax/blob/master/tests/nativehtmlgen.nim
@@ -41,7 +41,7 @@
 ##
 
 import
-  macros, strutils
+  std/[macros, strutils]
 
 const
   coreAttr* = " accesskey class contenteditable dir hidden id lang " &
@@ -8,7 +8,7 @@
 
 ## Do yourself a favor and import the module
-## as `from htmlgen import nil` and then fully qualify the macros.
+## as `from std/htmlgen import nil` and then fully qualify the macros.
 ##
 ## *Note*: The Karax project (`nimble install karax`) has a better